UnixStream

Struct UnixStream 

pub struct UnixStream(pub(super) Socket);
🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)
Available on Windows only.
A Unix stream socket.

Under Windows, it will only work starting from Windows 10 17063.

Examples

#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;
use std::io::prelude::*;

fn main() -> std::io::Result<()> {
    let mut stream = UnixStream::connect("/path/to/my/socket")?;
    stream.write_all(b"hello world")?;
    let mut response = String::new();
    stream.read_to_string(&mut response)?;
    println!("{response}");
    Ok(())
}

Tuple Fields

0: Socket
🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Implementations

Source

impl UnixStream

pub fn connect<P: AsRef<Path>>(path: P) -> Result<UnixStream>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Connects to the socket named by path.

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;

let socket = match UnixStream::connect("/tmp/sock") {
    Ok(sock) => sock,
    Err(e) => {
        println!("Couldn't connect: {e:?}");
        return
    }
};
pub fn connect_addr(socket_addr: &SocketAddr) -> Result<UnixStream>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Connects to the socket specified by address.

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::{UnixListener, UnixStream};

fn main() -> std::io::Result<()> {
    let listener = UnixListener::bind("/path/to/the/socket")?;
    let addr = listener.local_addr()?;

    let sock = match UnixStream::connect_addr(&addr) {
        Ok(sock) => sock,
        Err(e) => {
            println!("Couldn't connect: {e:?}");
            return Err(e)
        }
    };
    Ok(())
}
pub fn local_addr(&self) -> Result<SocketAddr>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Returns the socket address of the local half of this connection.

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    let addr = socket.local_addr().expect("Couldn't get local address");
    Ok(())
}
pub fn peer_addr(&self) -> Result<SocketAddr>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Returns the socket address of the remote half of this connection.

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    let addr = socket.peer_addr().expect("Couldn't get peer address");
    Ok(())
}
pub fn read_timeout(&self) -> Result<Option<Duration>>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Returns the read timeout of this socket.

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;
use std::time::Duration;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    socket.set_read_timeout(Some(Duration::new(1, 0))).expect("Couldn't set read timeout");
    assert_eq!(socket.read_timeout()?, Some(Duration::new(1, 0)));
    Ok(())
}
pub fn set_nonblocking(&self, nonblocking: bool) -> Result<()>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Moves the socket into or out of nonblocking mode.

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    socket.set_nonblocking(true).expect("Couldn't set nonblocking");
    Ok(())
}
pub fn set_read_timeout(&self, dur: Option<Duration>) -> Result<()>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Sets the read timeout for the socket.

If the provided value is None, then read calls will block indefinitely. An Err is returned if the zero Duration is passed to this method.

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;
use std::time::Duration;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    socket.set_read_timeout(Some(Duration::new(1, 0))).expect("Couldn't set read timeout");
    Ok(())
}

An Err is returned if the zero Duration is passed to this method:

#![feature(windows_unix_domain_sockets)]
use std::io;
use std::os::windows::net::UnixStream;
use std::time::Duration;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    let result = socket.set_read_timeout(Some(Duration::new(0, 0)));
    let err = result.unwrap_err();
    assert_eq!(err.kind(), io::ErrorKind::InvalidInput);
    Ok(())
}
pub fn set_write_timeout(&self, dur: Option<Duration>) -> Result<()>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Sets the write timeout for the socket.

If the provided value is None, then write calls will block indefinitely. An Err is returned if the zero Duration is passed to this method.

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;
use std::time::Duration;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    socket.set_write_timeout(Some(Duration::new(1, 0)))
        .expect("Couldn't set write timeout");
    Ok(())
}

An Err is returned if the zero Duration is passed to this method:

#![feature(windows_unix_domain_sockets)]
use std::io;
use std::os::windows::net::UnixStream;
use std::time::Duration;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    let result = socket.set_write_timeout(Some(Duration::new(0, 0)));
    let err = result.unwrap_err();
    assert_eq!(err.kind(), io::ErrorKind::InvalidInput);
    Ok(())
}
pub fn shutdown(&self, how: Shutdown) -> Result<()>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Shuts down the read, write, or both halves of this connection.

This function will cause all pending and future I/O calls on the specified portions to immediately return with an appropriate value (see the documentation of Shutdown).

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;
use std::net::Shutdown;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    socket.shutdown(Shutdown::Both).expect("shutdown function failed");
    Ok(())
}
pub fn take_error(&self) -> Result<Option<Error>>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Returns the value of the SO_ERROR option.

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    if let Ok(Some(err)) = socket.take_error() {
        println!("Got error: {err:?}");
    }
    Ok(())
}
pub fn try_clone(&self) -> Result<UnixStream>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Creates a new independently owned handle to the underlying socket.

The returned UnixStream is a reference to the same stream that this object references. Both handles will read and write the same stream of data, and options set on one stream will be propagated to the other stream.

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    let sock_copy = socket.try_clone().expect("Couldn't clone socket");
    Ok(())
}
pub fn write_timeout(&self) -> Result<Option<Duration>>

🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)

Returns the write timeout of this socket.

Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixStream;
use std::time::Duration;

fn main() -> std::io::Result<()> {
    let socket = UnixStream::connect("/tmp/sock")?;
    socket.set_write_timeout(Some(Duration::new(1, 0)))
        .expect("Couldn't set write timeout");
    assert_eq!(socket.write_timeout()?, Some(Duration::new(1, 0)));
    Ok(())
}